@@ -26,22 +26,31 @@ common_sub_args = [
         "dest": "dirty",
         "help": "Include dirty flag if applicable",
     },
+    {
+        "triggers": ["--tagged-metadata"],
+        "action": "store_true",
+        "dest": "tagged_metadata",
+        "help": "Include tagged metadata if applicable",
+    },
     {
         "triggers": ["--pattern"],
         "default": _VERSION_PATTERN,
         "help": (
             "Regular expression matched against the version source."
-            " This should contain one capture group named `base` corresponding to"
-            " the release segment of the source, and optionally another two groups"
-            " named `stage` and `revision` corresponding to a prerelease type"
-            " (such as 'alpha' or 'rc') and number (such as in 'alpha-2' or 'rc3')"
+            " This must contain one capture group named `base` corresponding to"
+            " the release segment of the source."
+            " Optionally, it may contain another two groups named `stage` and `revision`"
+            " corresponding to a prerelease type (such as 'alpha' or 'rc') and number"
+            " (such as in 'alpha-2' or 'rc3')."
+            " It may also contain a group named `tagged_metadata` corresponding to extra"
+            " metadata after the main part of the version (typically after a plus sign)."
         ),
     },
     {
         "triggers": ["--format"],
         "help": (
             "Custom output format. Available substitutions:"
-            " {base}, {stage}, {revision}, {distance}, {commit}, {dirty}"
+            " {base}, {stage}, {revision}, {distance}, {commit}, {dirty}, {tagged_metadata}"
         ),
     },
     {
@@ -202,9 +211,10 @@ def from_vcs(
     tag_dir: str,
     debug: bool,
     bump: bool,
+    tagged_metadata: bool,
 ) -> None:
     version = Version.from_vcs(vcs, pattern, latest_tag, tag_dir)
-    print(version.serialize(metadata, dirty, format, style, bump))
+    print(version.serialize(metadata, dirty, format, style, bump, tagged_metadata=tagged_metadata))
     if debug:
         print("# Matched tag: {}".format(version._matched_tag), file=sys.stderr)
         print("# Newer unmatched tags: {}".format(version._newer_unmatched_tags), file=sys.stderr)
@@ -226,6 +236,7 @@ def main() -> None:
                 tag_dir,
                 args.debug,
                 args.bump,
+                args.tagged_metadata,
             )
         elif args.command == "check":
             version = from_stdin(args.version)
